@@ -30,39 +30,20 @@ b = a + 543',
       str(
         modify(
           par1,
-          a = 4321,
-          c = 333
+          a = 4321
         )
       ),
-      'List of 3
+      'List of 2
  $ a:List of 2
   ..$ expr: num 4321',
       fixed = TRUE
     )
-    expect_output(
-      str(
-        modify(
-          par1,
-          a = 4321,
-          c = 333,
-          BEFORE = a
-        )
-      ),
-      'List of 3
- $ c:List of 2
-  ..$ expr: num 333',
-      fixed = TRUE
-    )
-    expect_equal(
-      length(
-        modify(
-          par1,
-          a = 4321,
-          c = 333,
-          BEFORE = a
-        )
-      ),
-      3
+    expect_error(
+      modify(
+        par1,
+        a = 4321,
+        c = 333
+      )
     )
     expect_error(
       modify(
@@ -74,6 +55,11 @@ b = a + 543',
       get_parameter_names(par1),
       c("a", "b")
     )
+    expect_output(
+      print(define_parameters()),
+      "0 unevaluated parameter.",
+      fixed = TRUE
+    )
   }
 )
 
